@@ -1,39 +1,25 @@
-import os, time
-import numpy as np
-from shutil import copyfile
-from ase.io import write
-import multiprocessing as mp
+import os
 import matplotlib.pyplot as plt
 
-from ase.calculators.calculator import Calculator
-
 from LatticeFinder.LatticeFinder.lattice_constant_generator import lattice_constant_generator
 
-from ase.lattice.cubic import SimpleCubic, FaceCenteredCubic, BodyCenteredCubic, Diamond
-from ase.lattice.tetragonal import SimpleTetragonal, CenteredTetragonal
-from ase.lattice.orthorhombic import SimpleOrthorhombic, BaseCenteredOrthorhombic, FaceCenteredOrthorhombic, BodyCenteredOrthorhombic
-from ase.lattice.monoclinic import SimpleMonoclinic, BaseCenteredMonoclinic
-from ase.lattice.triclinic import Triclinic
-from ase.lattice.hexagonal import Hexagonal, HexagonalClosedPacked, Graphite
-from ase.lattice.compounds import B1, B2, B3, L1_2, L1_0
-
 from LatticeFinder.LatticeFinder.examining_lattice_constant_methods_with_ASE         import get_energies_across_lattice_constants_ASE, get_system_from_ASE
 from LatticeFinder.LatticeFinder.examining_lattice_constant_methods_with_VASP        import get_energies_across_lattice_constants_VASP, get_system_from_VASP
 from LatticeFinder.LatticeFinder.examining_lattice_constant_methods_with_Manual_Mode import get_energies_across_lattice_constants_in_Manual_Mode, get_system_from_Manual_Mode
 
 from LatticeFinder.LatticeFinder.plotting_methods import plot_energy_vs_lattice_constants_1D, plot_energy_vs_lattice_constants_2D
 
-from LatticeFinder.LatticeFinder.other_methods import round_lattice_constant_parameters
+from LatticeFinder.LatticeFinder.other_methods import round_lattice_constant_parameters, get_lattice_type
 
 class LatticeFinder_Program:
 	"""
 	This program is designed to give plots and data to help obtain the optimal lattice constants for a 2D and 3D system.
 	"""
-	def __init__(self, symbol, lattice_type, lattice_constant_parameters, calculator, size=(1,1,1), directions=None, miller=None, limits=None, no_of_cpus=1, slurm_information={}):
+	def __init__(self, symbol, lattice_type, lattice_constant_parameters, calculator, size=(1,1,1), directions=None, miller=None, limits=None, make_svg_eps_files=True, no_of_cpus=1, slurm_information={}):
 		# input options required for obtaining lattice constants
 		self.check_input_information(symbol, lattice_type, lattice_constant_parameters, calculator, size, directions, miller, slurm_information)
 		# Information about how to make plots
-		self.check_output_information(limits)
+		self.check_output_information(limits, make_svg_eps_files)
 		# Other options
 		self.no_of_cpus = no_of_cpus
 		# show initial information
@@ -77,7 +63,7 @@ class LatticeFinder_Program:
 		# General options
 		self.symbol = symbol
 		self.lattice_type_name = str(lattice_type)
-		self.lattice_type = eval(lattice_type)
+		self.lattice_type = get_lattice_type(lattice_type)
 		self.lattice_constant_parameters = lattice_constant_parameters
 		self.calculator = calculator # This could be a string called 'VASP' or 'Manual Mode'
 		if isinstance(self.calculator,str):
@@ -105,12 +91,12 @@ class LatticeFinder_Program:
 		else:
 			self.make_packets = 'packet'
 
-	def check_output_information(self, limits):
+	def check_output_information(self, limits, make_svg_eps_files):
 		"""
 		This method will check the variables for making output data such as plots.
 		"""
 		# Plotting variables
-		if limits == None:
+		if limits is None:
 			if isinstance(limits,dict):
 				self.limits = {lc_key: None for lc_key in self.lattice_constant_parameters.keys()}
 			else:
@@ -130,6 +116,7 @@ class LatticeFinder_Program:
 				if value[1] is None:
 					value[1] = float('inf')
 				self.limits[key] = tuple(value)
+		self.make_svg_eps_files = make_svg_eps_files
 
 	############################################################################################################################
 
@@ -189,7 +176,6 @@ class LatticeFinder_Program:
 		print('===============================================================')
 		print('Loading data')
 		energies_vs_lattice_constants = {}
-		leading_data = False
 		with open(self.lattice_data_file,'r') as lattice_data_FILE:
 			for _ in range(12):
 				lattice_data_FILE.readline()
@@ -310,9 +296,9 @@ class LatticeFinder_Program:
 
 		"""
 		if len(self.lattice_constant_types) == 1:
-			plot_energy_vs_lattice_constants_1D(energies_vs_lattice_constants, self.limits, self.plotting_limits, self.minimum_energy, self.lowest_energy_lattice_constants)
+			plot_energy_vs_lattice_constants_1D(energies_vs_lattice_constants, self.limits, self.plotting_limits, self.minimum_energy, self.lowest_energy_lattice_constants, self.make_svg_eps_files)
 		if len(self.lattice_constant_types) == 2:
-			plot_energy_vs_lattice_constants_2D(energies_vs_lattice_constants, self.limits, self.plotting_limits, self.minimum_energy, self.lowest_energy_lattice_constants)
+			plot_energy_vs_lattice_constants_2D(energies_vs_lattice_constants, self.limits, self.plotting_limits, self.minimum_energy, self.lowest_energy_lattice_constants, self.make_svg_eps_files)
 
 	def get_other_data_about_system(self,minimum_energy,lowest_energy_lattice_constants,energy_vs_volumes=None):
 		"""
